%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Function Kuwada_Asym.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Nathan J. Kuwada and Paul A. Wiggins, 
% University of Washington. 
%
% 2014/10/17
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Description:
%
% Script To Analyze Asymmetric Partitioning 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% load data here

data_all = load( 'asymdata.mat' );

%%
data_all = data_all.data_all ;

dataLoadCons2 = data_all.loadCons2 ;

%% Look at malI

ind_malI = find(strcmp(data_all.labelsName, 'malI' ));
%ind_ilvE = find(strcmp(data_all.labelsName, 'ilvE' ));

ii = ind_malI(2);
figure(3)
clf;

fmo = data_all.asym_old_f{ii};
fmn = data_all.asym_new_f{ii};

fmax = max([fmo,fmn]);
fmin = min([fmo,fmn]);

% Iold = Inew line
loglog( [fmin,fmax], [fmin,fmax], 'g' );
hold on;

loglog(fmo ,fmn , 'r.' );

xlabel( 'i_{old} (AU/pixel)' );
ylabel( 'i_{new} (AU/pixel)' );


%% Make Histogram

fmo_ = fmo;
fmn_ = fmn;

ftot = fmo+fmn;
flagger = ftot>1.5e4;

fmo_ = fmo_(flagger);
fmn_ = fmn_(flagger);



clf;
[yy,xx] = hist3( [fmo_',fmn_'], {0:4e3:5e5,0:4e3:5e5}  );

imagesc( xx{1}, xx{2}, yy' );

jetter = jet(256);
jetter(1,:) = (jetter(1,:)+[1,1,1])/2;
colormap( jetter );

hold on;

plot( [fmin,fmax], [fmin,fmax], 'w:' );

axis( [0,1e5,0,1e5] );
set( gca, 'YDir', 'Normal' );

xlabel( 'Old Daughter Partition' );
ylabel( 'New Daughter Partition' );
title( 'MalI' );


%% Look at ilvE

ind_glpX = find(strcmp(data_all.labelsName, 'hisG' ));

ii = ind_glpX(2);
figure(3)
clf;

fmo = data_all.asym_old_f{ii};
fmn = data_all.asym_new_f{ii};

fmax = max([fmo,fmn]);
fmin = min([fmo,fmn]);

% Iold = Inew line
loglog( [fmin,fmax], [fmin,fmax], 'g' );
hold on;

loglog(fmo ,fmn , 'r.' );

xlabel( 'i_{old} (AU/pixel)' );
ylabel( 'i_{new} (AU/pixel)' );

%% Make Histogram

fmo_ = fmo;
fmn_ = fmn;

ftot = fmo+fmn;
flagger = ftot> 1.5e4;

fmo_ = fmo_(flagger);
fmn_ = fmn_(flagger);

clf;
[yy,xx] = hist3( [fmo_',fmn_'], {0:3e3:5e5,0:3e3:5e5}  );
imagesc( xx{1}, xx{2}, yy' );

jetter = jet(256);
jetter(1,:) = (jetter(1,:)+[1,1,1])/2;
colormap( jetter );

hold on;

plot( [fmin,fmax], [fmin,fmax], 'w:' );

axis( [0,1e5,0,1e5] );
set( gca, 'YDir', 'Normal' );

xlabel( 'Old Daughter Partition' );
ylabel( 'New Daughter Partition' );
title( 'HisG' );


%% Look at uidR

ind_glpX = find(strcmp(data_all.labelsName, 'uidR' ));

ii = ind_glpX(1);
figure(3)
clf;

fmo = data_all.asym_old_f{ii};
fmn = data_all.asym_new_f{ii};

fmax = max([fmo,fmn]);
fmin = min([fmo,fmn]);

loglog( [fmin,fmax], [fmin,fmax], 'g' );
hold on;

loglog(fmo ,fmn , 'r.' );

xlabel( 'i_{old} (AU/pixel)' );
ylabel( 'i_{new} (AU/pixel)' );

%% Make Histogram

fmo_ = fmo;
fmn_ = fmn;

ftot = fmo+fmn;
flagger = ftot>5e3;

fmo_ = fmo_(flagger);
fmn_ = fmn_(flagger);

clf;
[yy,xx] = hist3( [fmo_',fmn_'], {0:1e3:5e5,0:1e3:5e5}  );
imagesc( xx{1}, xx{2}, yy' );

jetter = jet(256);
jetter(1,:) = (jetter(1,:)+[1,1,1])/2;
colormap( jetter );

hold on;

plot( [fmin,fmax], [fmin,fmax], 'w:' );

axis( [0,5e4,0,5e4] );
set( gca, 'YDir', 'Normal' );

xlabel( 'Old Daughter Partition (AU)' );
ylabel( 'New Daughter Partition (AU)' );
title( 'UidR' );

%% show protein asymmetry

% min number of cells needed to plot
num_cut = 100;

ind_n = and( (data_all.asym_new_num > num_cut),...
             (data_all.asym_old_num > num_cut) );
                  
aom  = [data_all.asym_old_mean];
anm  = [data_all.asym_new_mean];

aom_n = aom(ind_n);
anm_n = anm(ind_n);

figure(1)
clf;

a = max( [aom,anm] );

chi2   = aom_n./(aom_n+anm_n);
chi2Cp = 0.52;
chi2Cm = 0.48;

loglog( [1,a],[1,a],'g' );
hold on;
ind = and( chi2>chi2Cm, chi2<chi2Cp );

loglog( aom_n(ind),anm_n(ind),'.g');

loglog( aom_n(chi2>chi2Cp),anm_n(chi2>chi2Cp),'.r');
loglog( aom_n(chi2<chi2Cm),anm_n(chi2<chi2Cm),'.b');

legend( {'I_{new} = I_{old}', 'I_{new} \approx I_{old}',...
         'I_{new} < I_{old}', 'I_{new} > I_{old}'},...
         'Location', 'NorthWest' );

ylabel( 'I_{new} (AU)' );
xlabel( 'I_{old} (AU)' );

axis( [1e2,1e6,1e2,1e6] );

%%

ind_malI = find(strcmp(data_all.labelsName(ind_n), 'malI' ))
ind_ilvE = find(strcmp(data_all.labelsName(ind_n), 'ilvE' ))

loglog( aom_n(ind_malI),anm_n(ind_malI),'*c');
loglog( aom_n(ind_ilvE),anm_n(ind_ilvE),'*m');



 