%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Script Kuwada_Distance.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Nathan J. Kuwada and Paul A. Wiggins, 
% University of Washington. 
%
% 2014/10/17
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Description:
%
% Matlab Script to Compute Distance Matrix from Consenus Images
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% Load data
data = load('localizome_data.mat' );


%% Show the images:
figure(1);
im = makeMosaicRGB( data.imColCell, [], 0, data.labelsName );

%% Make number labels
numLoc  = numel(data.imGrayCell); 

labelNum = {};
for ii = 1:numLoc
    
    labelNum{ii} = num2str(ii);
end

%% Make the variables for Distance Matrix

ssaa = [85 55];
vlen = ssaa(1)*ssaa(2);
A = zeros( numLoc, vlen );
dA = A;

for ii = 1:numLoc
    tmp = double(imresize( data.imGrayCell{ii}, ssaa ));
    A(ii,:) = tmp(:)'/sqrt(sum(tmp(:).*tmp(:)));     
end


meanVec = mean(A);
meanIm  = reshape( meanVec, ssaa );

for ii = 1:numLoc
    dA(ii,:) = A(ii,:) - meanVec;  
    tmp = dA(ii,:)/sqrt(sum(dA(ii,:).*dA(ii,:)));
    
    if ii == 1
        locC =  (double(tmp(:))*double(tmp(:))');
    else
        locC = locC +  (double(tmp(:))*double(tmp(:))');
    end
end


%% Sort Consensus images using hirerachical clustering

Ared = A(:,:) ;
ss = size( Ared ) ;
Z = linkage( Ared ) ;
[H,T,perm] = dendrogram( Z, 0 ) ;
A = A(perm,:) ;

%% Compute Distance matrix

A2 = A*A';
A2D = diag(A2);

ssA2 = size( A2 ); 

DM = -2*A2 + A2D*ones( 1, ssA2(1) ) + ones( ssA2(1), 1)*A2D';

%%

figure(60);
M = sqrt(DM);
imshow( M, [] );
colormap jet



