%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Script Kuwada_PCA.m
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Nathan J. Kuwada and Paul A. Wiggins, 
% University of Washington. 
%
% 2014/10/17
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Description:
%
% Script to Compute Principal Componets From Consensus Images
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Load up consensus images from file

data = load('localizome_data.mat');

%% Make the variables for PCA

mag = 4;
numLoc  = numel(data.imGrayCell); 
ssaa = size(imresize( data.imGrayCell{1}, 1/mag ));
vlen = ssaa(1)*ssaa(2);
A = zeros( numLoc, vlen );
dA = A;


for ii = 1:numLoc
    tmp = double(imresize( data.imGrayCell{ii}, 1/mag ));
    A(ii,:) = tmp(:)'/sqrt(sum(tmp(:).*tmp(:)));     
end

meanVec = mean(A);
meanIm  = reshape( meanVec, ssaa );

imshow( meanIm, [] );
colormap jet

for ii = 1:numLoc
    dA(ii,:) = A(ii,:) - meanVec;  
    tmp = dA(ii,:);
    
    if ii == 1
        locC =  (double(tmp(:))*double(tmp(:))');
    else
        locC = locC +  (double(tmp(:))*double(tmp(:))');
    end
end

%%  Compute Principal Components

[A,B] = eig( locC );

%% reorder from most to least significant

BB = B( end:-1:1, end:-1:1 );
AA = A( :, end:-1:1 );

%% Show Principal Components

figure(8);
clf;
numEig = 8;

imEig = cell( 1, numEig );

for ii = 1:numEig;
    imEig{ii} = reshape( AA(:,ii), size( meanIm ) );
    imshow( imEig{ii}, [] );
    makehotcold(true);
    drawnow;
end

%% PCA

figure(7);
clf;

loglog( diag( BB ), '.-r')

ylabel('Power' );
xlabel( 'PCA component' );

%% show PC mosaic 
figure(8)
clf;
imEigMos = makeMosaicBW( imEig(1:8) );
makehotcold(false);




